@@ -1258,7 +1258,9 @@ import.mirt<-function(mod,display=TRUE,digits=3) {
 
 	vcov<-try(extract.mirt(mod,what="vcov"))
 	if(inherits(vcov,"try-error")) warning(vcov)
-
+	if(grepl("Error",vcov[1,1])) {
+	  warning(vcov[1,1],"Suggestion: use another option for SE.type in the mirt function.")
+	}
 	if (all(dim(vcov)>c(1,1))) {
 		vcov<-vcov[!apply(is.na(vcov),1,all),]
 		vcov<-vcov[,!apply(is.na(vcov),2,all)]
